%define upstream_name vosk-api
%define source_name vosk-api-go
%define devname %mklibname vosk -d

Name:           python-vosk-api
Summary:        Speech recognition toolkit
Version:        0.3.46
Release:        %mkrel 1
URL:            https://github.com/alphacep/vosk-api
Source0:        https://github.com/alphacep/vosk-api/archive/refs/tags/go/v%{version}.tar.gz
License:        ASL 2.0
Group:          Development/Python

BuildRequires: pkgconfig(python3)
BuildRequires: python3dist(cffi)
BuildRequires: kaldi-vosk-devel
BuildRequires: openblas-devel
BuildRequires: libatomic-devel
BuildRequires: lapack-devel
BuildRequires: openfst-devel
BuildRequires: f2c


%description
Vosk is an offline open source speech recognition toolkit. It enables speech recognition models for 18 languages and dialects.
Vosk models provide continuous large vocabulary transcription, zero-latency response with streaming API, reconfigurable vocabulary and speaker identification.
This package provides Python bindings.


%package -n python3-%{upstream_name}
Summary:        Vosk-api bindings for Python 3
%{?python_provide:%python_provide python3-%{upstream_name}}


%description -n python3-%{upstream_name}
Vosk-api bindings for Python.

%package -n %{devname}
Summary:        Vosk-api devel files
Provides:   libvosk-devel = %{version}

%description -n %{devname}
Vosk-api devel files


%prep
%autosetup -n %{upstream_name}-go-v%{version} -p1

# disable stripping
sed -i -e '/$(CXX)/s/-s\s\+//' src/Makefile

# don't override system LDFLAGS
sed -i -e '/^LDFLAGS=$/d' src/Makefile

%build
pushd src
export EXTRA_CFLAGS="%{build_cflags}"
export LDFLAGS="%{build_ldflags}"
%ifarch i586
export EXTRA_CFLAGS="${EXTRA_CFLAGS} -msse2 -mfpmath=sse"
%endif
make USE_SHARED=1
popd
pushd python
%pyproject_wheel
popd

%install
install -m 0755 -vd                     %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_libdir}
install %{_builddir}/%{source_name}-v%{version}/src/vosk_api.h %{buildroot}%{_includedir}/vosk_api.h
%pyproject_install
%pyproject_save_files vosk
ln -s %{buildroot}%{python3_sitearch}/vosk/libvosk.so %{buildroot}%{_libdir}/

%files -n python3-%{upstream_name} -f %{pyproject_files}
%doc README.md
%license COPYING
%{_bindir}/vosk-transcriber
%{_libdir}/libvosk.so

%files -n %{devname}
%doc README.md
%license COPYING
%{_includedir}/vosk_api.h


%changelog
* Sun Feb 25 2024 papoteur <papoteur> 0.3.46-1.mga10
+ Revision: 2044132
- new version 0.3.46

* Fri Dec 29 2023 tv <tv> 0.3.45-3.mga10
+ Revision: 2023467
- Rebuild for python-3.12

* Sat Sep 30 2023 papoteur <papoteur> 0.3.45-2.mga10
+ Revision: 1992524
- add header file in a devel package for use with go compiler (see numen)

* Wed Sep 06 2023 papoteur <papoteur> 0.3.45-1.mga10
+ Revision: 1984840
- new 0.3.45

* Wed Sep 21 2022 wally <wally> 0.3.43-3.mga9
+ Revision: 1891143
- add patch to create properly named python wheels during the build
- enable debug pkg
- build using our compiler flags

* Tue Sep 20 2022 papoteur <papoteur> 0.3.43-2.mga9
+ Revision: 1890713
- workaround whl not installable on i586 and arm arches
- imported package python-vosk-api

